@@ -320,13 +320,14 @@ class LangJavaFx(LangJava):
         self.cssFile = None
         self.scenebuilderPos = "/opt/SceneBuilder/app"
         self.updateScript = self.dsrc / "update_files.sh"
+        self.module = self.dsrc / "module-info.java"
 
     def __writeToFiles(self):
         for gotFile in self.dsrc.rglob("*.java"):
             with open(gotFile, "w") as file:
                 if gotFile.stem == "Main":
                     if not self.fxmlFile:
-                        file.writelines(f"""package com.{self.packageName.replace('/', '.')}
+                        file.writelines(f"""package com.{self.packageName.replace('/', '.')};
 
 import javafx.application.Application;
 import javafx.stage.Stage;
@@ -339,7 +340,7 @@ public class {gotFile.stem} extends Application {{
 \tpublic void start(Stage primaryStage) throws Exception {{
 \t\tGridPane root = new GridPane();
 \t\tprimaryStage.setTitle("{self.projName}");
-\t\tprimaryStage.setScene(new Scene(root, "400", "400"));
+\t\tprimaryStage.setScene(new Scene(root, 400, 400));
 \t\tprimaryStage.show();
 \t}}
 \tpublic static void main(String ...args) {{
@@ -347,7 +348,7 @@ public class {gotFile.stem} extends Application {{
 \t}}
 }}""")
                     else:
-                        file.writelines(f"""package com.{self.packageName.replace('/', '.')}
+                        file.writelines(f"""package com.{self.packageName.replace('/', '.')};
 
 import javafx.application.Application;
 import javafx.stage.Stage;
@@ -359,9 +360,9 @@ public class {gotFile.stem} extends Application {{
 
 \t@Override
 \tpublic void start(Stage primaryStage) throws Exception {{
-\t\tParent root = new FXMLLoader(getClass().getResource("/com/{self.packageName}/{self.fxmlFile}"));
+\t\tParent root = FXMLLoader.load(getClass().getResource("/com/{self.packageName}/{self.fxmlFile}"));
 \t\tprimaryStage.setTitle("{self.projName}");
-\t\tprimaryStage.setScene(new Scene(root, "400", "400"));
+\t\tprimaryStage.setScene(new Scene(root, 400, 400));
 \t\tprimaryStage.show();
 \t}}
 \tpublic static void main(String ...args) {{
@@ -370,7 +371,7 @@ public class {gotFile.stem} extends Application {{
 }}""")
                 # going to be Controller or some other java files
                 else:
-                    file.writelines(f"""package com.{self.packageName.replace('/', '.')}
+                    file.writelines(f"""package com.{self.packageName.replace('/', '.')};
 
 public class {gotFile.stem} {{
 \t/** code here */
@@ -390,13 +391,23 @@ public class {gotFile.stem} {{
                 file.write("/* provide styling here */")
         if self.scenebuilderPos:
             if Path(self.scenebuilderPos).is_dir():
-                with open(Path(self.scenebuilderPos + '/' + self.fxmlFile), 'w') as file:
+                with open(Path(self.scenebuilderPos + '/' + (self.fxmlFile + '.fxml')), 'w') as file:
                     file.writelines("""<?import javafx.geometry.Insets?>
 <?import javafx.scene.layout.GridPane?>
 
 <GridPane fx:controller="" xmlns:fx="http://javafx.com/fxml">
 \t<!-- code here -->
 </GridPane>""")
+        with open(Path(self.module), 'w') as file:
+            file.writelines(f"""/** module file for project */
+
+module com.{self.packageName.replace('/', '.')} {{
+\trequires javafx.fxml;
+\trequires javafx.controls;
+
+\topens com.{self.packageName.replace('/', '.')} to javafx.fxml, javafx.graphics;
+}}
+                            """)
         with open(Path(self.updateScript), 'w') as file:
             file.writelines(f"""#!/usr/bin/env bash
 
@@ -427,6 +438,8 @@ rsync -a {self.dsrc}/{self.packageName}/{Path(self.fxmlFile).stem}.fxml {self.db
             Path.touch(self.packageDir / (self.cssFile + ".css"))
         (self.dbin / ('com.' + self.packageName.replace('/', '.'))).mkdir()  # create module
         LangJavaFx.__writeToFiles(self)
+        # or just do 0o754
+        Path(self.updateScript).chmod(492)  # octal permission is 754(4 + 40 + 448)
 
 class LangServlet(SetProject):
     """ further project setup for Java Servlet languages """
